/*
 * SceneGroup.cpp
 *
 *  Created on: Feb 12, 2009
 *      Author: jima
 */

#include "SceneInstance.h"
#include "SceneGroup.h"


SceneGroup::SceneGroup()
{
    _name = "unassigned";

    _sphere = NULL;
    _light = NULL;
    _camera = NULL;
}

// don't delete children, just local stuff; freeing children is SceneLoader's job
// (because cleaning up after a DAG with only local info is not good)
SceneGroup::~SceneGroup() 
{
    delete _sphere;
    delete _light;
    delete _camera;
}

int SceneGroup::getChildCount()
{
    return int(_children.size());
}

SceneInstance *SceneGroup::getChild(int i) {
    return _children[i];
}

string SceneGroup::getName() {
    return _name;
}

bool SceneGroup::computeSphere(double &radius, MaterialInfo &material, int time) { /* get a sphere by its radius */
    if (_sphere == NULL)
        return false;
    
    radius = _sphere->getRadius(time);
    material = _sphere->getMaterial(time);
    
    return true;
}

bool SceneGroup::computeLight(LightInfo &ld, int time) { /* get light parameters */
    if (_light == NULL)
        return false;
    else
        ld = _light->getLight(time);
    return true;
}

bool SceneGroup::computeCamera(CameraInfo &cam, int time) { /* get camera frustum */
    if (_camera == NULL)
        return false;
    else
        cam = _camera->getCamera(time);
    return true;
}

